## Module for command simplification when using Python with the AWR Design Environment 

AWR Design Environment Python module that wraps lower level API commands into higher level function calls

# Installation
    pip install pyawr-utils

# Upgrade

    pip install --upgrade pyawr-utils

# Requirements
* Python >= 3.7
* pyawr
* numpy

# Usage

    See https://kb.awr.com/display/awrscripts/Pyawr+Utilities for details
	
# History

# 0.1
* Beta version
# 0.11
* Fixed PyPI Installation and Upgrade commands

